@@ -1,3 +1,4 @@
+import os
 import tifffile
 import colorcet
 import struct
@@ -330,7 +331,7 @@ class IJTiffFile:
         wp@tl20200214
     """
     def __init__(self, path, shape, dtype='uint16', colors=None, colormap=None, pxsize=None, deltaz=None,
-                 timeinterval=None, **extratags):
+                 timeinterval=None, compression=(8, 9), comment=None, **extratags):
         assert len(shape) >= 3, 'please specify all c, z, t for the shape'
         assert len(shape) <= 3, 'please specify only c, z, t for the shape'
         assert np.dtype(dtype).char in 'BbHhf', 'datatype not supported'
@@ -344,6 +345,8 @@ class IJTiffFile:
         self.pxsize = pxsize
         self.deltaz = deltaz
         self.timeinterval = timeinterval
+        self.compression = compression
+        self.comment = comment
         self.extratags = {} if extratags is None else Tag.to_tags(extratags)
         if pxsize is not None:
             pxsize = Tag.fraction(pxsize)
@@ -378,9 +381,9 @@ class IJTiffFile:
 
     def ij_tiff_frame(self, frame):
         with BytesIO() as framedata:
-            with tifffile.TiffWriter(framedata, self.header.bigtiff, self.header.byteorder) as t:
+            with tifffile.TiffWriter(framedata, bigtiff=self.header.bigtiff, byteorder=self.header.byteorder) as t:
                 # predictor=True might save a few bytes, but requires the package imagecodes to save floats
-                t.write(frame, compression=(8, 9), contiguous=True, predictor=False)
+                t.write(frame, compression=self.compression, contiguous=True, predictor=False)
             return framedata.getvalue()
 
     def save(self, frame, c, z, t, **extratags):
@@ -440,17 +443,27 @@ class IJTiffFile:
         else:
             desc.extend((f'images={np.prod(self.shape)}', f'channels={self.shape[0]}', f'slices={self.shape[1]}',
                          f'frames={self.shape[2]}'))
-        desc.extend(('hyperstack=true', 'mode=composite', 'loop=false', 'unit=micron'))
+        if self.shape[0] == 1:
+            desc.append('mode=grayscale')
+        else:
+            desc.append('mode=composite')
+        desc.extend(('hyperstack=true', 'loop=false', 'unit=micron'))
         if self.deltaz is not None:
             desc.append(f'spacing={self.deltaz}')
         if self.timeinterval is not None:
             desc.append(f'finterval={self.timeinterval}')
-        return bytes('\n'.join(desc), 'ascii')
+        desc = [bytes(d, 'ascii') for d in desc]
+        if self.comment is not None:
+            desc.append(b'')
+            if isinstance(self.comment, bytes):
+                desc.append(self.comment)
+            else:
+                desc.append(bytes(self.comment, 'ascii'))
+        return b'\n'.join(desc)
 
     @cached_property
     def empty_frame(self):
-        ifd = self.ifds[list(self.ifds.keys())[-1]].copy()
-        return self.compress_frame(np.zeros((ifd[257].value[0], ifd[256].value[0]), self.dtype))
+        return self.compress_frame(np.zeros(self.frame_shape, self.dtype))
 
     @cached_property
     def frame_shape(self):
@@ -482,46 +495,50 @@ class IJTiffFile:
                                                dtype=int).T.flatten()]) for color in self.colors]
 
     def close(self):
-        assert len(self.frames_added) >= 1, 'at least one frame should be added to the tiff'
         if multiprocessing.current_process().pid == self.main_pid:
             self.pool_manager.close(self)
             with self.fh.lock() as fh:
-                if len(self.frames_written) < np.prod(self.shape):  # add empty frames if needed
-                    for n in product(*[range(i) for i in self.shape]):
-                        if n not in self.frames_written:
-                            self.add_empty_frame(n)
+                if len(self.frames_added) == 0:
+                    warn('At least one frame should be added to the tiff, removing file.')
+                    fh.close()
+                    os.remove(self.path)
+                else:
+                    if len(self.frames_written) < np.prod(self.shape):  # add empty frames if needed
+                        for n in product(*[range(i) for i in self.shape]):
+                            if n not in self.frames_written:
+                                self.add_empty_frame(n)
 
-                for n, tags in self.frame_extra_tags.items():
-                    framenr, channel = self.get_frame_number(n)
-                    self.ifds[framenr].update(tags)
-                if self.colormap is not None:
-                    self.ifds[0][320] = Tag('SHORT', self.colormap_bytes)
-                    self.ifds[0][262] = Tag('SHORT', 3)
-                if self.colors is not None:
-                    for c, color in enumerate(self.colors_bytes):
-                        self.ifds[c][320] = Tag('SHORT', color)
-                        self.ifds[c][262] = Tag('SHORT', 3)
-                if 306 not in self.ifds[0]:
-                    self.ifds[0][306] = Tag('ASCII', datetime.now().strftime('%Y:%m:%d %H:%M:%S'))
-                for framenr in range(self.nframes):
-                    stripbyteoffsets, stripbytecounts = zip(*[self.strips[(framenr, channel)]
-                                                              for channel in range(self.spp)])
-                    self.ifds[framenr][258].value = self.spp * self.ifds[framenr][258].value
-                    self.ifds[framenr][270] = Tag('ASCII', self.description)
-                    self.ifds[framenr][273] = Tag('LONG8', sum(stripbyteoffsets, []))
-                    self.ifds[framenr][277] = Tag('SHORT', self.spp)
-                    self.ifds[framenr][279] = Tag('LONG8', sum(stripbytecounts, []))
-                    self.ifds[framenr][305] = Tag('ASCII', 'tiffwrite_tllab_NKI')
-                    if self.extratags is not None:
-                        self.ifds[framenr].update(self.extratags)
-                    if self.colormap is None and self.colors is None and self.shape[0] > 1:
-                        self.ifds[framenr][284] = Tag('SHORT', 2)
-                    self.ifds[framenr].write(fh, self.header, self.write)
-                    if framenr:
-                        self.ifds[framenr].write_offset(self.ifds[framenr - 1].where_to_write_next_ifd_offset)
-                    else:
-                        self.ifds[framenr].write_offset(self.header.offset - self.header.offsetsize)
-            fh.close()
+                    for n, tags in self.frame_extra_tags.items():
+                        framenr, channel = self.get_frame_number(n)
+                        self.ifds[framenr].update(tags)
+                    if self.colormap is not None:
+                        self.ifds[0][320] = Tag('SHORT', self.colormap_bytes)
+                        self.ifds[0][262] = Tag('SHORT', 3)
+                    if self.colors is not None:
+                        for c, color in enumerate(self.colors_bytes):
+                            self.ifds[c][320] = Tag('SHORT', color)
+                            self.ifds[c][262] = Tag('SHORT', 3)
+                    if 306 not in self.ifds[0]:
+                        self.ifds[0][306] = Tag('ASCII', datetime.now().strftime('%Y:%m:%d %H:%M:%S'))
+                    for framenr in range(self.nframes):
+                        stripbyteoffsets, stripbytecounts = zip(*[self.strips[(framenr, channel)]
+                                                                  for channel in range(self.spp)])
+                        self.ifds[framenr][258].value = self.spp * self.ifds[framenr][258].value
+                        self.ifds[framenr][270] = Tag('ASCII', self.description)
+                        self.ifds[framenr][273] = Tag('LONG8', sum(stripbyteoffsets, []))
+                        self.ifds[framenr][277] = Tag('SHORT', self.spp)
+                        self.ifds[framenr][279] = Tag('LONG8', sum(stripbytecounts, []))
+                        self.ifds[framenr][305] = Tag('ASCII', 'tiffwrite_tllab_NKI')
+                        if self.extratags is not None:
+                            self.ifds[framenr].update(self.extratags)
+                        if self.colormap is None and self.colors is None and self.shape[0] > 1:
+                            self.ifds[framenr][284] = Tag('SHORT', 2)
+                        self.ifds[framenr].write(fh, self.header, self.write)
+                        if framenr:
+                            self.ifds[framenr].write_offset(self.ifds[framenr - 1].where_to_write_next_ifd_offset)
+                        else:
+                            self.ifds[framenr].write_offset(self.header.offset - self.header.offsetsize)
+                    fh.close()
 
     def __enter__(self):
         return self
@@ -595,19 +612,20 @@ class PoolManager:
         self.tifs.pop(tif.path)
         if not self.tifs:
             self.__class__.instance = None
-            self.is_alive = False
-            self.done.set()
-            while not self.queue.empty():
-                self.queue.get()
-            self.queue.close()
-            self.queue.join_thread()
-            while not self.error_queue.empty():
-                print(self.error_queue.get())
-            self.error_queue.close()
-            self.ifd_queue.close()
-            self.ifd_queue.join_thread()
-            self.pool.close()
-            self.pool.join()
+            if self.is_alive:
+                self.is_alive = False
+                self.done.set()
+                while not self.queue.empty():
+                    self.queue.get()
+                self.queue.close()
+                self.queue.join_thread()
+                while not self.error_queue.empty():
+                    print(self.error_queue.get())
+                self.error_queue.close()
+                self.ifd_queue.close()
+                self.ifd_queue.join_thread()
+                self.pool.close()
+                self.pool.join()
 
     def get_ifds_from_queue(self):
         while not self.ifd_queue.empty():
